/* A Bison parser, made from configparser.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_CONFIGPARSER_TAB_H
# define BISON_CONFIGPARSER_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     LEFTBRACE_WCP = 258,
     RIGHTBRACE_WCP = 259,
     GLOBAL_WCP = 260,
     COLORS_WCP = 261,
     LANG_WCP = 262,
     PALETTE_WCP = 263,
     OWNOP_WCP = 264,
     LISTERSETS_WCP = 265,
     YES_WCP = 266,
     NO_WCP = 267,
     LEFT_WCP = 268,
     RIGHT_WCP = 269,
     HBARTOP_WCP = 270,
     HBARHEIGHT_WCP = 271,
     VBARLEFT_WCP = 272,
     VBARWIDTH_WCP = 273,
     DISPLAYSETS_WCP = 274,
     NAME_WCP = 275,
     SIZE_WCP = 276,
     TYPE_WCP = 277,
     PERMISSION_WCP = 278,
     OWNER_WCP = 279,
     DESTINATION_WCP = 280,
     MODTIME_WCP = 281,
     ACCTIME_WCP = 282,
     CHGTIME_WCP = 283,
     ROWS_WCP = 284,
     COLUMNS_WCP = 285,
     CACHESIZE_WCP = 286,
     OWNERSTYLE_WCP = 287,
     TERMINAL_WCP = 288,
     USESTRINGFORDIRSIZE_WCP = 289,
     TIMESETS_WCP = 290,
     STYLE1_WCP = 291,
     STYLE2_WCP = 292,
     STYLE3_WCP = 293,
     DATE_WCP = 294,
     TIME_WCP = 295,
     DATESUBSTITUTION_WCP = 296,
     DATEBEFORETIME_WCP = 297,
     STATEBAR_WCP = 298,
     SELLVBAR_WCP = 299,
     UNSELLVBAR_WCP = 300,
     CLOCKBAR_WCP = 301,
     REQUESTER_WCP = 302,
     UNSELDIR_WCP = 303,
     SELDIR_WCP = 304,
     UNSELFILE_WCP = 305,
     SELFILE_WCP = 306,
     UNSELACTDIR_WCP = 307,
     SELACTDIR_WCP = 308,
     UNSELACTFILE_WCP = 309,
     SELACTFILE_WCP = 310,
     LVBG_WCP = 311,
     STARTUP_WCP = 312,
     BUTTON_WCP = 313,
     BUTTONS_WCP = 314,
     POSITION_WCP = 315,
     TITLE_WCP = 316,
     COMMANDS_WCP = 317,
     SHORTKEYS_WCP = 318,
     PATHS_WCP = 319,
     PATH_WCP = 320,
     FILETYPES_WCP = 321,
     FILETYPE_WCP = 322,
     NORMAL_WCP = 323,
     NOTYETCHECKED_WCP = 324,
     UNKNOWN_WCP = 325,
     NOSELECT_WCP = 326,
     DIR_WCP = 327,
     USEPATTERN_WCP = 328,
     USECONTENT_WCP = 329,
     PATTERN_WCP = 330,
     CONTENT_WCP = 331,
     FTCOMMANDS_WCP = 332,
     DND_WCP = 333,
     DC_WCP = 334,
     SHOW_WCP = 335,
     RAWSHOW_WCP = 336,
     USER_WCP = 337,
     FLAGS_WCP = 338,
     IGNOREDIRS_WCP = 339,
     HOTKEYS_WCP = 340,
     HOTKEY_WCP = 341,
     FONTS_WCP = 342,
     GLOBALFONT_WCP = 343,
     BUTTONFONT_WCP = 344,
     LEFTFONT_WCP = 345,
     RIGHTFONT_WCP = 346,
     CLOCKBARSETS_WCP = 347,
     MODUS_WCP = 348,
     TIMESPACE_WCP = 349,
     VERSION_WCP = 350,
     EXTERN_WCP = 351,
     UPDATETIME_WCP = 352,
     PROGRAM_WCP = 353,
     KEY_WCP = 354,
     DOUBLE_WCP = 355,
     MOD_WCP = 356,
     CONTROL_WCP = 357,
     SHIFT_WCP = 358,
     LOCK_WCP = 359,
     MOD1_WCP = 360,
     MOD2_WCP = 361,
     MOD3_WCP = 362,
     MOD4_WCP = 363,
     MOD5_WCP = 364,
     DNDACTION_WCP = 365,
     DCACTION_WCP = 366,
     SHOWACTION_WCP = 367,
     RSHOWACTION_WCP = 368,
     USERACTION_WCP = 369,
     ROWUP_WCP = 370,
     ROWDOWN_WCP = 371,
     CHANGEHIDDENFLAG_WCP = 372,
     COPYOP_WCP = 373,
     FIRSTROW_WCP = 374,
     LASTROW_WCP = 375,
     PAGEUP_WCP = 376,
     PAGEDOWN_WCP = 377,
     SELECTOP_WCP = 378,
     SELECTALLOP_WCP = 379,
     SELECTNONEOP_WCP = 380,
     INVERTALLOP_WCP = 381,
     PARENTDIROP_WCP = 382,
     ENTERDIROP_WCP = 383,
     CHANGELISTERSETOP_WCP = 384,
     SWITCHLISTEROP_WCP = 385,
     FILTERSELECTOP_WCP = 386,
     FILTERUNSELECTOP_WCP = 387,
     PATHTOOTHERSIDEOP_WCP = 388,
     QUITOP_WCP = 389,
     DELETEOP_WCP = 390,
     RELOADOP_WCP = 391,
     MAKEDIROP_WCP = 392,
     RENAMEOP_WCP = 393,
     DIRSIZEOP_WCP = 394,
     SIMDDOP_WCP = 395,
     STARTPROGOP_WCP = 396,
     SEARCHENTRYOP_WCP = 397,
     ENTERPATHOP_WCP = 398,
     SCROLLLISTEROP_WCP = 399,
     CREATESYMLINKOP_WCP = 400,
     CHANGESYMLINKOP_WCP = 401,
     CHMODOP_WCP = 402,
     TOGGLELISTERMODEOP_WCP = 403,
     SETSORTMODEOP_WCP = 404,
     SETFILTEROP_WCP = 405,
     SHORTKEYFROMLISTOP_WCP = 406,
     CHOWNOP_WCP = 407,
     WORKERCONFIG_WCP = 408,
     USERSTYLE_WCP = 409,
     DATESTRING_WCP = 410,
     TIMESTRING_WCP = 411,
     COLOR_WCP = 412,
     PATTERNIGNORECASE_WCP = 413,
     PATTERNUSEREGEXP_WCP = 414,
     PATTERNUSEFULLNAME_WCP = 415,
     COM_WCP = 416,
     SEPARATEEACHENTRY_WCP = 417,
     RECURSIVE_WCP = 418,
     START_WCP = 419,
     TERMINALWAIT_WCP = 420,
     SHOWOUTPUT_WCP = 421,
     VIEWSTR_WCP = 422,
     INBACKGROUND_WCP = 423,
     TAKEDIRS_WCP = 424,
     ACTIONNUMBER_WCP = 425,
     HIDDENFILES_WCP = 426,
     HIDE_WCP = 427,
     TOGGLE_WCP = 428,
     FOLLOWSYMLINKS_WCP = 429,
     MOVE_WCP = 430,
     RENAME_WCP = 431,
     SAMEDIR_WCP = 432,
     REQUESTDEST_WCP = 433,
     REQUESTFLAGS_WCP = 434,
     OVERWRITE_WCP = 435,
     ALWAYS_WCP = 436,
     NEVER_WCP = 437,
     COPYMODE_WCP = 438,
     FAST_WCP = 439,
     PRESERVEATTR_WCP = 440,
     MODE_WCP = 441,
     ACTIVE_WCP = 442,
     ACTIVE2OTHER_WCP = 443,
     SPECIAL_WCP = 444,
     REQUEST_WCP = 445,
     CURRENT_WCP = 446,
     OTHER_WCP = 447,
     FILTER_WCP = 448,
     QUICK_WCP = 449,
     ALSOACTIVE_WCP = 450,
     RESETDIRSIZES_WCP = 451,
     KEEPFILETYPES_WCP = 452,
     RELATIVE_WCP = 453,
     ONFILES_WCP = 454,
     ONDIRS_WCP = 455,
     SORTBY_WCP = 456,
     SORTFLAG_WCP = 457,
     REVERSE_WCP = 458,
     DIRLAST_WCP = 459,
     DIRMIXED_WCP = 460,
     EXCLUDE_WCP = 461,
     INCLUDE_WCP = 462,
     UNSET_WCP = 463,
     UNSETALL_WCP = 464,
     SCRIPTOP_WCP = 465,
     NOP_WCP = 466,
     PUSH_WCP = 467,
     LABEL_WCP = 468,
     IF_WCP = 469,
     END_WCP = 470,
     POP_WCP = 471,
     SETTINGS_WCP = 472,
     WINDOW_WCP = 473,
     GOTO_WCP = 474,
     PUSHUSEOUTPUT_WCP = 475,
     DODEBUG_WCP = 476,
     WPURECURSIVE_WCP = 477,
     WPUTAKEDIRS_WCP = 478,
     STACKNR_WCP = 479,
     PUSHSTRING_WCP = 480,
     IFTEST_WCP = 481,
     IFLABEL_WCP = 482,
     WINTYPE_WCP = 483,
     OPEN_WCP = 484,
     CLOSE_WCP = 485,
     LEAVE_WCP = 486,
     CHANGEPROGRESS_WCP = 487,
     CHANGETEXT_WCP = 488,
     PROGRESSUSEOUTPUT_WCP = 489,
     WINTEXTUSEOUTPUT_WCP = 490,
     PROGRESS_WCP = 491,
     WINTEXT_WCP = 492,
     SHOWDIRCACHEOP_WCP = 493,
     INODE_WCP = 494,
     NLINK_WCP = 495,
     BLOCKS_WCP = 496,
     SHOWHEADER_WCP = 497,
     LVHEADER_WCP = 498,
     IGNORECASE_WCP = 499,
     LISTVIEWS_WCP = 500,
     BLL_WCP = 501,
     LBL_WCP = 502,
     LLB_WCP = 503,
     BL_WCP = 504,
     LB_WCP = 505,
     LAYOUT_WCP = 506,
     BUTTONSVERT_WCP = 507,
     LISTVIEWSVERT_WCP = 508,
     EXTCOND_WCP = 509,
     USEEXTCOND_WCP = 510,
     SUBTYPE_WCP = 511,
     PARENTACTIONOP_WCP = 512,
     NOOPERATIONOP_WCP = 513,
     COLORMODE_WCP = 514,
     DEFAULT_WCP = 515,
     CUSTOM_WCP = 516,
     UNSELECTCOLOR_WCP = 517,
     SELECTCOLOR_WCP = 518,
     UNSELECTACTIVECOLOR_WCP = 519,
     SELECTACTIVECOLOR_WCP = 520,
     COLOREXTERNPROG_WCP = 521,
     PARENT_WCP = 522,
     DONTCD_WCP = 523,
     DONTCHECKVIRTUAL_WCP = 524,
     GOFTPOP_WCP = 525,
     HOSTNAME_WCP = 526,
     USERNAME_WCP = 527,
     PASSWORD_WCP = 528,
     DONTENTERFTP_WCP = 529,
     ALWAYSSTOREPW_WCP = 530,
     ERROR = 531,
     ACTIVESIDE_WCP = 532,
     SHOWFREESPACE_WCP = 533,
     ACTIVEMODE_WCP = 534,
     ASK_WCP = 535,
     SSHALLOW_WCP = 536,
     STRING_WCP = 537,
     NUM_WCP = 538
   };
#endif
#define LEFTBRACE_WCP 258
#define RIGHTBRACE_WCP 259
#define GLOBAL_WCP 260
#define COLORS_WCP 261
#define LANG_WCP 262
#define PALETTE_WCP 263
#define OWNOP_WCP 264
#define LISTERSETS_WCP 265
#define YES_WCP 266
#define NO_WCP 267
#define LEFT_WCP 268
#define RIGHT_WCP 269
#define HBARTOP_WCP 270
#define HBARHEIGHT_WCP 271
#define VBARLEFT_WCP 272
#define VBARWIDTH_WCP 273
#define DISPLAYSETS_WCP 274
#define NAME_WCP 275
#define SIZE_WCP 276
#define TYPE_WCP 277
#define PERMISSION_WCP 278
#define OWNER_WCP 279
#define DESTINATION_WCP 280
#define MODTIME_WCP 281
#define ACCTIME_WCP 282
#define CHGTIME_WCP 283
#define ROWS_WCP 284
#define COLUMNS_WCP 285
#define CACHESIZE_WCP 286
#define OWNERSTYLE_WCP 287
#define TERMINAL_WCP 288
#define USESTRINGFORDIRSIZE_WCP 289
#define TIMESETS_WCP 290
#define STYLE1_WCP 291
#define STYLE2_WCP 292
#define STYLE3_WCP 293
#define DATE_WCP 294
#define TIME_WCP 295
#define DATESUBSTITUTION_WCP 296
#define DATEBEFORETIME_WCP 297
#define STATEBAR_WCP 298
#define SELLVBAR_WCP 299
#define UNSELLVBAR_WCP 300
#define CLOCKBAR_WCP 301
#define REQUESTER_WCP 302
#define UNSELDIR_WCP 303
#define SELDIR_WCP 304
#define UNSELFILE_WCP 305
#define SELFILE_WCP 306
#define UNSELACTDIR_WCP 307
#define SELACTDIR_WCP 308
#define UNSELACTFILE_WCP 309
#define SELACTFILE_WCP 310
#define LVBG_WCP 311
#define STARTUP_WCP 312
#define BUTTON_WCP 313
#define BUTTONS_WCP 314
#define POSITION_WCP 315
#define TITLE_WCP 316
#define COMMANDS_WCP 317
#define SHORTKEYS_WCP 318
#define PATHS_WCP 319
#define PATH_WCP 320
#define FILETYPES_WCP 321
#define FILETYPE_WCP 322
#define NORMAL_WCP 323
#define NOTYETCHECKED_WCP 324
#define UNKNOWN_WCP 325
#define NOSELECT_WCP 326
#define DIR_WCP 327
#define USEPATTERN_WCP 328
#define USECONTENT_WCP 329
#define PATTERN_WCP 330
#define CONTENT_WCP 331
#define FTCOMMANDS_WCP 332
#define DND_WCP 333
#define DC_WCP 334
#define SHOW_WCP 335
#define RAWSHOW_WCP 336
#define USER_WCP 337
#define FLAGS_WCP 338
#define IGNOREDIRS_WCP 339
#define HOTKEYS_WCP 340
#define HOTKEY_WCP 341
#define FONTS_WCP 342
#define GLOBALFONT_WCP 343
#define BUTTONFONT_WCP 344
#define LEFTFONT_WCP 345
#define RIGHTFONT_WCP 346
#define CLOCKBARSETS_WCP 347
#define MODUS_WCP 348
#define TIMESPACE_WCP 349
#define VERSION_WCP 350
#define EXTERN_WCP 351
#define UPDATETIME_WCP 352
#define PROGRAM_WCP 353
#define KEY_WCP 354
#define DOUBLE_WCP 355
#define MOD_WCP 356
#define CONTROL_WCP 357
#define SHIFT_WCP 358
#define LOCK_WCP 359
#define MOD1_WCP 360
#define MOD2_WCP 361
#define MOD3_WCP 362
#define MOD4_WCP 363
#define MOD5_WCP 364
#define DNDACTION_WCP 365
#define DCACTION_WCP 366
#define SHOWACTION_WCP 367
#define RSHOWACTION_WCP 368
#define USERACTION_WCP 369
#define ROWUP_WCP 370
#define ROWDOWN_WCP 371
#define CHANGEHIDDENFLAG_WCP 372
#define COPYOP_WCP 373
#define FIRSTROW_WCP 374
#define LASTROW_WCP 375
#define PAGEUP_WCP 376
#define PAGEDOWN_WCP 377
#define SELECTOP_WCP 378
#define SELECTALLOP_WCP 379
#define SELECTNONEOP_WCP 380
#define INVERTALLOP_WCP 381
#define PARENTDIROP_WCP 382
#define ENTERDIROP_WCP 383
#define CHANGELISTERSETOP_WCP 384
#define SWITCHLISTEROP_WCP 385
#define FILTERSELECTOP_WCP 386
#define FILTERUNSELECTOP_WCP 387
#define PATHTOOTHERSIDEOP_WCP 388
#define QUITOP_WCP 389
#define DELETEOP_WCP 390
#define RELOADOP_WCP 391
#define MAKEDIROP_WCP 392
#define RENAMEOP_WCP 393
#define DIRSIZEOP_WCP 394
#define SIMDDOP_WCP 395
#define STARTPROGOP_WCP 396
#define SEARCHENTRYOP_WCP 397
#define ENTERPATHOP_WCP 398
#define SCROLLLISTEROP_WCP 399
#define CREATESYMLINKOP_WCP 400
#define CHANGESYMLINKOP_WCP 401
#define CHMODOP_WCP 402
#define TOGGLELISTERMODEOP_WCP 403
#define SETSORTMODEOP_WCP 404
#define SETFILTEROP_WCP 405
#define SHORTKEYFROMLISTOP_WCP 406
#define CHOWNOP_WCP 407
#define WORKERCONFIG_WCP 408
#define USERSTYLE_WCP 409
#define DATESTRING_WCP 410
#define TIMESTRING_WCP 411
#define COLOR_WCP 412
#define PATTERNIGNORECASE_WCP 413
#define PATTERNUSEREGEXP_WCP 414
#define PATTERNUSEFULLNAME_WCP 415
#define COM_WCP 416
#define SEPARATEEACHENTRY_WCP 417
#define RECURSIVE_WCP 418
#define START_WCP 419
#define TERMINALWAIT_WCP 420
#define SHOWOUTPUT_WCP 421
#define VIEWSTR_WCP 422
#define INBACKGROUND_WCP 423
#define TAKEDIRS_WCP 424
#define ACTIONNUMBER_WCP 425
#define HIDDENFILES_WCP 426
#define HIDE_WCP 427
#define TOGGLE_WCP 428
#define FOLLOWSYMLINKS_WCP 429
#define MOVE_WCP 430
#define RENAME_WCP 431
#define SAMEDIR_WCP 432
#define REQUESTDEST_WCP 433
#define REQUESTFLAGS_WCP 434
#define OVERWRITE_WCP 435
#define ALWAYS_WCP 436
#define NEVER_WCP 437
#define COPYMODE_WCP 438
#define FAST_WCP 439
#define PRESERVEATTR_WCP 440
#define MODE_WCP 441
#define ACTIVE_WCP 442
#define ACTIVE2OTHER_WCP 443
#define SPECIAL_WCP 444
#define REQUEST_WCP 445
#define CURRENT_WCP 446
#define OTHER_WCP 447
#define FILTER_WCP 448
#define QUICK_WCP 449
#define ALSOACTIVE_WCP 450
#define RESETDIRSIZES_WCP 451
#define KEEPFILETYPES_WCP 452
#define RELATIVE_WCP 453
#define ONFILES_WCP 454
#define ONDIRS_WCP 455
#define SORTBY_WCP 456
#define SORTFLAG_WCP 457
#define REVERSE_WCP 458
#define DIRLAST_WCP 459
#define DIRMIXED_WCP 460
#define EXCLUDE_WCP 461
#define INCLUDE_WCP 462
#define UNSET_WCP 463
#define UNSETALL_WCP 464
#define SCRIPTOP_WCP 465
#define NOP_WCP 466
#define PUSH_WCP 467
#define LABEL_WCP 468
#define IF_WCP 469
#define END_WCP 470
#define POP_WCP 471
#define SETTINGS_WCP 472
#define WINDOW_WCP 473
#define GOTO_WCP 474
#define PUSHUSEOUTPUT_WCP 475
#define DODEBUG_WCP 476
#define WPURECURSIVE_WCP 477
#define WPUTAKEDIRS_WCP 478
#define STACKNR_WCP 479
#define PUSHSTRING_WCP 480
#define IFTEST_WCP 481
#define IFLABEL_WCP 482
#define WINTYPE_WCP 483
#define OPEN_WCP 484
#define CLOSE_WCP 485
#define LEAVE_WCP 486
#define CHANGEPROGRESS_WCP 487
#define CHANGETEXT_WCP 488
#define PROGRESSUSEOUTPUT_WCP 489
#define WINTEXTUSEOUTPUT_WCP 490
#define PROGRESS_WCP 491
#define WINTEXT_WCP 492
#define SHOWDIRCACHEOP_WCP 493
#define INODE_WCP 494
#define NLINK_WCP 495
#define BLOCKS_WCP 496
#define SHOWHEADER_WCP 497
#define LVHEADER_WCP 498
#define IGNORECASE_WCP 499
#define LISTVIEWS_WCP 500
#define BLL_WCP 501
#define LBL_WCP 502
#define LLB_WCP 503
#define BL_WCP 504
#define LB_WCP 505
#define LAYOUT_WCP 506
#define BUTTONSVERT_WCP 507
#define LISTVIEWSVERT_WCP 508
#define EXTCOND_WCP 509
#define USEEXTCOND_WCP 510
#define SUBTYPE_WCP 511
#define PARENTACTIONOP_WCP 512
#define NOOPERATIONOP_WCP 513
#define COLORMODE_WCP 514
#define DEFAULT_WCP 515
#define CUSTOM_WCP 516
#define UNSELECTCOLOR_WCP 517
#define SELECTCOLOR_WCP 518
#define UNSELECTACTIVECOLOR_WCP 519
#define SELECTACTIVECOLOR_WCP 520
#define COLOREXTERNPROG_WCP 521
#define PARENT_WCP 522
#define DONTCD_WCP 523
#define DONTCHECKVIRTUAL_WCP 524
#define GOFTPOP_WCP 525
#define HOSTNAME_WCP 526
#define USERNAME_WCP 527
#define PASSWORD_WCP 528
#define DONTENTERFTP_WCP 529
#define ALWAYSSTOREPW_WCP 530
#define ERROR 531
#define ACTIVESIDE_WCP 532
#define SHOWFREESPACE_WCP 533
#define ACTIVEMODE_WCP 534
#define ASK_WCP 535
#define SSHALLOW_WCP 536
#define STRING_WCP 537
#define NUM_WCP 538




#ifndef YYSTYPE
#line 192 "configparser.y"
typedef union {
  int num;
  char *strptr;
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 611 "configparser.tab.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_CONFIGPARSER_TAB_H */

